@@ -2,12 +2,12 @@ context("genome_join")
 
 library(dplyr)
 
-x1 <- tibble(id = 1:4,
+x1 <- tibble::tibble(id = 1:4,
              chromosome = c("chr1", "chr1", "chr2", "chr2"),
              start = c(100, 200, 300, 400),
              end = c(150, 250, 350, 450))
 
-x2 <- tibble(id = 1:4,
+x2 <- tibble::tibble(id = 1:4,
              chromosome = c("chr1", "chr2", "chr2", "chr1"),
              start = c(140, 210, 400, 300),
              end = c(160, 240, 415, 320))
@@ -56,3 +56,4 @@ test_that("genome_join throws an error if not given three columns", {
 
   expect_error(genome_inner_join(x1, x2, by = c("start", "end")), "three columns")
 })
+
